summaryrefslogtreecommitdiffstats
path: root/release/sysinstall
diff options
context:
space:
mode:
authorjkh <jkh@FreeBSD.org>2000-02-18 07:09:45 +0000
committerjkh <jkh@FreeBSD.org>2000-02-18 07:09:45 +0000
commit44c4a7d34d23fc3793b5dcb89e93ddc830db14f4 (patch)
treedf4873ef09e68fda34d768d3aace6ac18ce93b86 /release/sysinstall
parenteb6cba145ae2b83af2593a9ff5b8162519c39bac (diff)
downloadFreeBSD-src-44c4a7d34d23fc3793b5dcb89e93ddc830db14f4.zip
FreeBSD-src-44c4a7d34d23fc3793b5dcb89e93ddc830db14f4.tar.gz
Don't call it a Novice install, call it Standard.
Also say thousands of packages, not hundreds.
Diffstat (limited to 'release/sysinstall')
-rw-r--r--release/sysinstall/dispatch.c2
-rw-r--r--release/sysinstall/install.c9
-rw-r--r--release/sysinstall/menus.c4
-rw-r--r--release/sysinstall/sysinstall.84
-rw-r--r--release/sysinstall/sysinstall.h2
5 files changed, 11 insertions, 10 deletions
diff --git a/release/sysinstall/dispatch.c b/release/sysinstall/dispatch.c
index 811bae5..7d8dc9c 100644
--- a/release/sysinstall/dispatch.c
+++ b/release/sysinstall/dispatch.c
@@ -81,7 +81,7 @@ static struct _word {
{ "docShowDocument", docShowDocument },
{ "installCommit", installCommit },
{ "installExpress", installExpress },
- { "installNovice", installNovice },
+ { "installStandard", installStandard },
{ "installUpgrade", installUpgrade },
{ "installFixupBin", installFixupBin },
{ "installFixupXFree", installFixupXFree },
diff --git a/release/sysinstall/menus.c b/release/sysinstall/menus.c
index 52e1239..b9924d4 100644
--- a/release/sysinstall/menus.c
+++ b/release/sysinstall/menus.c
@@ -277,7 +277,7 @@ DMenu MenuIndex = {
{ " FTP sites", "The FTP mirror site listing.", NULL, dmenuSubmenu, NULL, &MenuMediaFTP },
{ " Gateway", "Set flag to route packets between interfaces.", dmenuVarCheck, dmenuToggleVariable, NULL, "gateway=YES" },
{ " HTML Docs", "The HTML documentation menu", NULL, docBrowser },
- { " Install, Novice", "A novice system installation.", NULL, installNovice },
+ { " Install, Standard", "A standard system installation.", NULL, installStandard },
{ " Install, Express", "An express system installation.", NULL, installExpress },
{ " Install, Custom", "The custom installation menu", NULL, dmenuSubmenu, NULL, &MenuInstallCustom },
{ " Label", "The disk Label editor", NULL, diskLabelEditor },
@@ -333,7 +333,7 @@ DMenu MenuInitial = {
{ { "Select" },
{ "X Exit Install", NULL, NULL, dmenuExit },
{ " Usage", "Quick start - How to use this menu system", NULL, dmenuDisplayFile, NULL, "usage" },
- { "Novice", "Begin a novice installation (for beginners)", NULL, installNovice },
+ { "Standard", "Begin a standard installation (recommended)", NULL, installStandard },
{ "Express", "Begin a quick installation (for the impatient)", NULL, installExpress },
{ " Custom", "Begin a custom installation (for experts)", NULL, dmenuSubmenu, NULL, &MenuInstallCustom },
{ "Configure", "Do post-install configuration of FreeBSD", NULL, dmenuSubmenu, NULL, &MenuConfigure },
diff --git a/release/sysinstall/sysinstall.8 b/release/sysinstall/sysinstall.8
index 33552fa..66b10d1 100644
--- a/release/sysinstall/sysinstall.8
+++ b/release/sysinstall/sysinstall.8
@@ -614,8 +614,8 @@ Start an "express" installation, asking few questions of
the user.
.Pp
\fBVariables:\fR None
-.It installNovice
-Start a "novice" installation, the most user-friendly
+.It installStandard
+Start a "standard" installation, the most user-friendly
installation type available.
.Pp
\fBVariables:\fR None
diff --git a/release/sysinstall/sysinstall.h b/release/sysinstall/sysinstall.h
index c395785..ce25f58 100644
--- a/release/sysinstall/sysinstall.h
+++ b/release/sysinstall/sysinstall.h
@@ -558,7 +558,7 @@ extern Boolean checkLabels(Boolean whinge, Chunk **rdev, Chunk **sdev, Chunk **u
extern int installCommit(dialogMenuItem *self);
extern int installCustomCommit(dialogMenuItem *self);
extern int installExpress(dialogMenuItem *self);
-extern int installNovice(dialogMenuItem *self);
+extern int installStandard(dialogMenuItem *self);
extern int installFixitHoloShell(dialogMenuItem *self);
extern int installFixitCDROM(dialogMenuItem *self);
extern int installFixitFloppy(dialogMenuItem *self);
OpenPOWER on IntegriCloud
diff --git a/release/sysinstall/install.c b/release/sysinstall/install.c
index 5f187b7..38c22cc 100644
--- a/release/sysinstall/install.c
+++ b/release/sysinstall/install.c
@@ -459,14 +459,14 @@ installExpress(dialogMenuItem *self)
return i;
}
/* Novice mode installation */
int
-installNovice(dialogMenuItem *self)
+installStandard(dialogMenuItem *self)
{
int i, tries = 0;
Device **devs;
- variable_set2(SYSTEM_STATE, "novice", 0);
+ variable_set2(SYSTEM_STATE, "standard", 0);
dialog_clear_norefresh();
#ifndef __alpha__
msgConfirm("In the next menu, you will need to set up a DOS-style (\"fdisk\") partitioning\n"
@@ -579,7 +579,7 @@ nodisks:
}
dialog_clear_norefresh();
- if (!msgYesNo("The FreeBSD package collection is a collection of hundreds of ready-to-run\n"
+ if (!msgYesNo("The FreeBSD package collection is a collection of thousands of ready-to-run\n"
"applications, from text editors to games to WEB servers and more. Would you\n"
"like to browse the collection now?")) {
(void)configPackages(self);
@@ -1050,6 +1050,7 @@ installVarDefaults(dialogMenuItem *self)
else
variable_set2(SYSTEM_STATE, "init", 0);
variable_set2(VAR_NEWFS_ARGS, "-b 8192 -f 1024", 0);
+ variable_set2(VAR_MOUSED_PORT, "/dev/psm0", 0);
return DITEM_SUCCESS;
}
@@ -459,14 +459,14 @@ installExpress(dialogMenuItem *self)
return i;
}
-/* Novice mode installation */
+/* Standard mode installation */
int